[Bug tree-optimization/106809] [12/13 regression] large bison grammars compilation got a lot slower, mainly due to -Wuninitialized
marxin at gcc dot gnu.org
gcc-bugzilla@gcc.gnu.org
Fri Sep 2 07:16:29 GMT 2022
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=106809
--- Comment #4 from Martin Liška <marxin at gcc dot gnu.org> ---
I see the change since r12-4726-g9a27acc30a34b785 which goes from 2.2s to 6.3s
(checking enabled).
More information about the Gcc-bugs
mailing list